Scheduler - Rabbyt Reference

Documentation Index | From module rabbyt.

# Scheduler

`Scheduler()`

Scheduler provides... (wait for it...) scheduling!

You may create your own scheduler instances, or use the default `rabbyt.scheduler`

## Methods

### add

`add(time, callback)`

Schedules a `callback` to be called at a given `time`.

### pump

`pump([time])`

Calls all callbacks that have been scheduled for before `time`.

If `time` is not given, the value returned by `rabbyt.get_time()` will be used.